# Public Information

## What is SWIFT?

SWIFT is a Smoothed Particle Hydrodynamics code for Astrophysics. What does
that even mean? It is a computer program designed for running on supercomputers
that simulates forces upon particles due to two main things: gravity and 
hydrodynamics (forces that arise from fluids rubbing against each other).
This turns out to be quite a complicated problem as we can't build
computers large enough to simulate down to an atomic level. This means 
we need to re-think the equations that describe the particles and how they
interact. It turns out that we must solve the equations that describe these problems
numerically, which requires a lot of computing power and fast computer code.

We use SWIFT to run simulations of Astrophysical objects, such as galaxies.
We do this to test theories about how the Universe came about and evolved from
the big bang up to the present day!

<div class="videowrapper"><iframe width="100%" height="100%" src="https://www.youtube.com/embed/UJYV6f8SwdQ" frameborder="0" allowfullscreen></iframe>
</div>

## Why create SWIFT?

We created SWIFT for a number of reasons. The primary reason beings that we want
to be able to simulate a whole Universe! This has been attempted before (see
[the EAGLE Project](http://icc.dur.ac.uk/Eagle) and [the Illustris project](
http://www.illustris-project.org) for more details), but the codes used to do
this have always been rather slow and difficult to modify. SWIFT aims to remedy
that by choosing to parallelise the problem in a different way and by
having a more modular structure than other codes making it easier for users to
pick and choose what physics they want to include in their simulation.

The way that supercomputers are constructed is not by having one huge superfast
'computer', but rather by having lots of different computers that are
connected together by high-speed networks. Therefore the way to speed up your
code might not necessarily be to make it 'run faster' on a single machine, but
rather enable those machines to talk to each other in a more efficient way.
This is how SWIFT is different from other codes that are used in Astrophysics
for a similar purpose.

Traditionally, you have each 'node' (computer) in the 'cluster' (supercomputer)
running the exact same code at the exact same time, and at the end of each bit
of the problem they all talk to each other and exchange information. SWIFT does
this a little differently, with each node working on different tasks than
others as and when those tasks need to be completed. This (theoretically)
should cut down on the time when a node is sitting and waiting for work, which
is just wasted time and electricity!

## What is SPH?

Smoothed Particle Hydrodynamics (SPH) is a method of calculating the forces
between fluid elements. Let's say that we want to simulate some water and a wave
within it. Even a liter of water has 100000000000000000000000000 particles in it.
To store that much data we would require a computer that as 100 trillion times as
much storage space as *all of the data on the internet*. It's clear that we need
a more efficient way of simulating this water if we are to have any hope!

It turns out that we can represent the water by many fewer particles (let's say
about 1000) if we can smooth over the gaps between them efficiently. Smoothed
Particle Hydrodynamics is the technique that we use to do that.
